Module extract

Module extract 

Extract System/Planet data from raw save discovery records.

Functions

extract_biome_from_vp
Extract biome and infested flag from a discovery record’s VP array.
extract_seed_from_vp
Extract seed hash from VP[0].
extract_systems
Build systems and planets from a parsed save file’s discovery records.